@@ -1,6 +1,8 @@
-from pytask.queue.queue import Queue
+from pytask.task_queue.task_queue import Queue
 from typing import Callable, Any
 from pytask.job import Job
+from pytask.worker.base_worker import BaseWorker
+from typing_extensions import override
 import time
 
 import logging
@@ -8,19 +10,22 @@ import logging
 logger = logging.getLogger(__name__)
 
 
-class Worker:
+class Worker(BaseWorker):
     def __init__(
         self,
         queue: Queue,
         func: Callable[[Job], Any],
         logger: logging.Logger | None = None,
-        interval: int = 0,
+        interval: int = 1,
     ):
         self.queue: Queue = queue
         self.func: Callable[[Job], Any] = func
         self.interval: int = interval
         self.logger: logging.Logger | None = logger
 
+        super().__init__(queue, func, logger, interval)
+
+    @override
     def run(self):
         while True:
             job = self.queue.get_oldest_pending()
@@ -48,6 +53,3 @@ class Worker:
 
             if self.interval > 0:
                 time.sleep(self.interval)
-
-    def do(self, job: Job):
-        self.func(job)
